/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher;

/**
 * Defines a task that is to run within the Basher framework.
 * <br/>
 * Implementations of this interface are encouraged to maintain the tasks small and to the point.  Overall, a collection
 * of small tasks should emulate a complete system more accurately.
 *
 * @author Johan Lindquist
 * @version 1.0
 */
public interface Task
{
    /**
     * Main method called by a component to execute this <code>Task</code>.  This should ensure that
     * counters of failures/successes are kept up to date.
     *
     * @throws Throwable The re-thrown exception thrown by the task
     */
    public void executeTask() throws Throwable;

}
