package net.sourceforge.basher.events;

import net.sourceforge.basher.BasherContext;

/**
 * @author Johan Lindquist
 * @version $Revision$
 */
public class ThreadAddedEvent extends BasherEvent
{
    private String _name;
    private int _currentNumberThreads;
    private final BasherContext _basherContext;

    /**
     * @param name
     * @param currentNumberThreads
     * @param basherContext
     */
    public ThreadAddedEvent(final String name, final int currentNumberThreads, final BasherContext basherContext)
    {
        _name = name;
        _currentNumberThreads = currentNumberThreads;
        _basherContext = basherContext;
    }

    /** Returns the name of the thread to stop
     *
     * @return The name of the thread which should be stopped.
     */
    public String getName()
    {
        return _name;
    }

    /** Retrieves the current number of threads running after the new thread was added
     *
     * @return The number of threads now running
     */
    public int getCurrentNumberThreads()
    {
        return _currentNumberThreads;
    }

    /** Retrives the <code>BasherContext</code> currently running.
     *
     * @return  The current Basher context
     */
    public BasherContext getBasherContext()
    {
        return _basherContext;
    }

    @Override
    public String toString()
    {
        return "ThreadAddedEvent{" +
                "_name='" + _name + '\'' +
                ", _currentNumberThreads=" + _currentNumberThreads +
                ", _basherContext=" + _basherContext +
                "} " + super.toString();
    }

    @Override
    public boolean equals(final Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }
        if (!super.equals(o))
        {
            return false;
        }

        final ThreadAddedEvent that = (ThreadAddedEvent) o;

        if (_currentNumberThreads != that._currentNumberThreads)
        {
            return false;
        }
        if (_basherContext != null ? !_basherContext.equals(that._basherContext) : that._basherContext != null)
        {
            return false;
        }
        if (_name != null ? !_name.equals(that._name) : that._name != null)
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = super.hashCode();
        result = 31 * result + (_name != null ? _name.hashCode() : 0);
        result = 31 * result + _currentNumberThreads;
        result = 31 * result + (_basherContext != null ? _basherContext.hashCode() : 0);
        return result;
    }
}