package net.sourceforge.basher.events;

/**
 * @author Johan Lindquist
 * @version $Revision$
 */
public class ThreadRemovedEvent extends BasherEvent
{
    private String _name;
    private int _currentNumberThreads;

    public ThreadRemovedEvent(final String name, final int currentNumberThreads)
    {
        _name = name;
        _currentNumberThreads = currentNumberThreads;
    }

    /**
     * Returns the name of the thread to stop
     *
     * @return The name of the thread which should be stopped.
     */
    public String getName()
    {
        return _name;
    }

    /**
     * Retrieves the current number of threads running after the new thread was removed
     *
     * @return The number of threads now running
     */
    public int getCurrentNumberThreads()
    {
        return _currentNumberThreads;
    }

    @Override
    public String toString()
    {
        return "ThreadRemovedEvent{" +
                "_name='" + _name + '\'' +
                ", _currentNumberThreads=" + _currentNumberThreads +
                "} " + super.toString();
    }

    @Override
    public boolean equals(final Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }
        if (!super.equals(o))
        {
            return false;
        }

        final ThreadRemovedEvent that = (ThreadRemovedEvent) o;

        if (_currentNumberThreads != that._currentNumberThreads)
        {
            return false;
        }
        if (_name != null ? !_name.equals(that._name) : that._name != null)
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = super.hashCode();
        result = 31 * result + (_name != null ? _name.hashCode() : 0);
        result = 31 * result + _currentNumberThreads;
        return result;
    }
}
