package net.sourceforge.basher.impl;

import java.util.List;

import net.sourceforge.basher.Task;
import net.sourceforge.basher.TaskConfiguration;

/** Gaderian configuration of a task.  Extends the <code>TaskConfiguration</code> by adding a task, class or object
 * instance.
 * @author Johan Lindquist
 */
public class TaskContribution extends TaskConfiguration
{
    private Task _task;
    private List<TaskContribution> _taskContributions;

    public TaskContribution(final Task task, final TaskConfiguration taskConfiguration)
    {
        this(task);
        initialize(taskConfiguration);
    }

    protected TaskContribution()
    {
    }

    public TaskContribution(final Task task)
    {
        _task = task;
    }

    public Task getTask()
    {
        return _task;
    }

    public void setTask( final Task task )
    {
        _task = task;
    }

    public void setFollowers( final List<TaskContribution> taskContributions )
    {
        _taskContributions = taskContributions;
    }

    public List<TaskContribution> getTaskContributions()
    {
        return _taskContributions;
    }

    @Override
    public boolean equals( final Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( !( o instanceof TaskContribution ) )
        {
            return false;
        }
        if ( !super.equals( o ) )
        {
            return false;
        }

        final TaskContribution that = ( TaskContribution ) o;

        if ( _task != null ? !_task.equals( that._task ) : that._task != null )
        {
            return false;
        }
        if ( _taskContributions != null ? !_taskContributions.equals( that._taskContributions ) : that._taskContributions != null )
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = super.hashCode();
        result = 31 * result + ( _task != null ? _task.hashCode() : 0 );
        result = 31 * result + ( _taskContributions != null ? _taskContributions.hashCode() : 0 );
        return result;
    }

    @Override
    public String toString()
    {
        return "TaskContribution{" +
                "_task=" + _task +
                ", _taskContributions=" + _taskContributions +
                "} " + super.toString();
    }
}
