package net.sourceforge.basher.internal.impl;

import java.util.List;

import bsh.*;
import net.sourceforge.basher.*;
import net.sourceforge.basher.events.EventManager;
import org.apache.commons.logging.Log;
import org.ops4j.gaderian.events.RegistryShutdownListener;

/**
 * @author Johan Lindquist
 * @version $Revision$
 */
public class BeanShellServer implements RegistryShutdownListener
{
    private List<String> _beanShellScripts;
    private Scheduler _scheduler;
    private Log _log;
    private TaskManager _taskManager;
    private EventManager _eventManager;
    private ContextManager _contextManager;

    private int _port;
    private Interpreter _interpreter;

    public void setBeanShellScripts(final List<String> beanShellScripts)
    {
        _beanShellScripts = beanShellScripts;
    }

    public void setTaskManager(final TaskManager taskManager)
    {
        _taskManager = taskManager;
    }

    public void setScheduler(final Scheduler scheduler)
    {
        _scheduler = scheduler;
    }

    public void setEventManager(final EventManager eventManager)
    {
        _eventManager = eventManager;
    }

    public void setContextManager(final ContextManager contextManager)
    {
        _contextManager = contextManager;
    }

    public void setPort(final int port)
    {
        _port = port;
    }

    public void setLog(final Log log)
    {
        _log = log;
    }

    public void initializeService() throws Exception
    {
        _log.info("Initializing Basher BeanShell Server");
        try
        {
            _interpreter = new Interpreter();

            // Export the scheduler
            _interpreter.set("scheduler", _scheduler);
            _interpreter.set("taskManager", _taskManager);
            _interpreter.set("eventManager", _eventManager);
            _interpreter.set("contextManager", _contextManager);

            _log.info("Loading '" + _beanShellScripts.size() + "' provided BeanShell script locations");
            for ( final String beanShellScript : _beanShellScripts )
            {
                _log.info("Importing commands from: " + beanShellScript);
                _interpreter.eval("importCommands(\""+ beanShellScript + "\")");
            }
            _log.info("Starting BeanShell HTTP daemon on port: " + _port);
            _interpreter.set("portnum", _port);
            _interpreter.eval("setAccessibility(true)"); // turn off access restrictions
            _interpreter.eval("server(portnum)");
            _log.info("BeanShell HTTP daemon started on port: " + _port);
        }
        catch (Throwable throwable)
        {
            final String errorMessage = "Unable to start the Basher BeanShell Server on port " + _port;

            _log.error(errorMessage);
            _log.error("Error: " + throwable.getMessage());

            throw new BasherException(errorMessage, throwable);
        }

        _log.info("Basher BeanShell Server started on port " + _port);

    }

    public void registryDidShutdown()
    {
        try
        {
            _interpreter.unset("scheduler");
            _interpreter.unset("taskManager");
            _interpreter.unset("eventManager");
            _interpreter.unset("contextManager");
        }
        catch (EvalError evalError)
        {
            evalError.printStackTrace();
        }
    }
}
