package net.sourceforge.basher.internal.impl;

import net.sourceforge.basher.*;
import net.sourceforge.basher.annotations.*;
import net.sourceforge.basher.internal.TaskConfigurationExtractor;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.NoOpLog;

/**
 * @author Johan Lindquist
 */
public class TaskConfigurationExtractorImpl implements TaskConfigurationExtractor
{
    private Log _log;

    public void setLog(final Log log)
    {
        _log = log;
    }

    public TaskConfiguration extractTaskConfiguration(final Class clazz)
    {
        TaskConfiguration taskConfiguration = createDefaultTaskConfiguration();

        // Process the specified class for annotations
        processAnnotations(clazz, taskConfiguration);

        return taskConfiguration;
        
    }

    private TaskConfiguration createDefaultTaskConfiguration()
    {
        // FIXME: this should really have a 'default' task configuration being provided to it
        return new TaskConfiguration();
    }

    private void processAnnotations(final Class<? extends Object> taskInstanceClass, final TaskConfiguration taskConfiguration)
    {
        // First examine super classes for annotations
        // By doing depth-first here, we allow sub-classes to override super classes annotations
        final Class superClass = taskInstanceClass.getSuperclass();
        if (!superClass.equals(Object.class))
        {
            processAnnotations(superClass, taskConfiguration);
        }

        // Determine whether the task is timed or not
        if (taskInstanceClass.isAnnotationPresent(BasherTimedTask.class))
        {
            BasherTimedTask annotation = taskInstanceClass.getAnnotation(BasherTimedTask.class);
            // taskConfiguration.setInterval(annotation.interval());
            // taskConfiguration.setTimed(true);
        }

        if (taskInstanceClass.isAnnotationPresent(BasherMaxTime.class))
        {
            BasherMaxTime annotation = taskInstanceClass.getAnnotation(BasherMaxTime.class);
            taskConfiguration.setMaxTime(annotation.time());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherMaxInvocations.class))
        {
            BasherMaxInvocations annotation = taskInstanceClass.getAnnotation(BasherMaxInvocations.class);
            taskConfiguration.setMaxInvocations(annotation.max());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherInertia.class))
        {
            BasherInertia annotation = taskInstanceClass.getAnnotation(BasherInertia.class);
            taskConfiguration.setInertia(annotation.inertia());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherName.class))
        {
            BasherName annotation = taskInstanceClass.getAnnotation(BasherName.class);
            taskConfiguration.setTaskName(((BasherName) annotation).name());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherStopAfter.class))
        {
            BasherStopAfter annotation = taskInstanceClass.getAnnotation(BasherStopAfter.class);
            taskConfiguration.setStopAfter(((BasherStopAfter) annotation).time());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherWeight.class))
        {
            BasherWeight annotation = taskInstanceClass.getAnnotation(BasherWeight.class);
            taskConfiguration.setWeight(((BasherWeight) annotation).weight());
        }
        if (taskInstanceClass.isAnnotationPresent(BasherRunFrom.class))
        {
            BasherRunFrom annotation = taskInstanceClass.getAnnotation(BasherRunFrom.class);
            taskConfiguration.setRunFrom(((BasherRunFrom) annotation).time());
        }

        if (taskInstanceClass.isAnnotationPresent(BasherPhases.class))
        {
            taskConfiguration.clearApplicablePhases();
            Phase[] phases = taskInstanceClass.getAnnotation(BasherPhases.class).phases();
            if (phases != null)
            {
                for (Phase phase : phases)
                {
                    taskConfiguration.addApplicablePhase(phase);
                }
            }
        }

        if (taskConfiguration.getApplicablePhases().size() == 0)
        {
            _log.warn("No applicable phase specified for task");
        }

    }


}
